@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2021 Aspose.Cells Cloud
+Copyright (c) 2022 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -133,7 +133,7 @@ __PACKAGE__->method_documentation({
     	read_only => '',
     		},
     'criteria' => {
-    	datatype => 'object',
+    	datatype => 'string',
     	base_name => 'Criteria',
     	description => '',
     	format => '',
@@ -143,7 +143,7 @@ __PACKAGE__->method_documentation({
 
 __PACKAGE__->swagger_types( {
     'filter_operator_type' => 'string',
-    'criteria' => 'object'
+    'criteria' => 'string'
 } );
 
 __PACKAGE__->attribute_map( {
